==> faq-system-0.3.1.tar.gz: faq-system-0.3.1/answer.cc <==
#include "conf.h"

int main(void)
{
	//int i;
	char **tuple;
	Database *db;
	DBResult *res;

	db = new Database();

	cgi C;
        C.initPage();

	string instance;
        instance = C.get_value("instance");
        config CONF(instance);

        const char* MYDATABASE;
        const char* MYTOPIC; 
        const char* MYANSWER;
        const char* MYQUESTION;
        MYDATABASE = CONF.MYDATABASE.c_str();
        MYTOPIC = CONF.MYTOPIC.c_str();
        MYANSWER = CONF.MYANSWER.c_str();  
        MYQUESTION = CONF.MYQUESTION.c_str();


	// Initialise the database - for future releases
	if (db->init() != DB_COMMAND_OK) {
		fprintf(stdout, "Unable to initialize database: %s\n\n", 
		        db->errorMessage());
		exit(1);
        }
	// Connect to database on localhost
        if (db->connect("localhost", "", MYDATABASE) != DB_CONNECTION_OK) {
        fprintf(stdout, "Unable connect to database '%s': %s\n\n",
                 MYDATABASE, db->errorMessage());
                 exit(1);
        }
	
	string stage, question_id, topic_id, keys, answer;
	question_id = C.get_value("question_id");
	answer = C.get_value("answer");
	keys = C.get_value("keys");
	stage = C.get_value("stage");

        topic_id = C.get_value("topic_id");
        question_id = C.get_value("question_id");

	HTML h;
        cout << h.html()
        << h.body("#ffffff") << endl;

	if( stage == "prepare")
	{
		res = db->exec("SELECT value FROM %s WHERE question_id = '%s'", MYQUESTION, question_id.c_str());
		tuple = res->getTuple();
                while (tuple != NULL)
                {
			cout << "<h2>" << *(tuple) << "</h2>\n";
			tuple = res->getTuple();
                }
                cout << "<form name=answer action=\"" << URL << "/" << ADMIN << "/answer.cgi\" method=post>" << endl
                << h.font("arial","2")
                << "Answer this question."
                << h._font() << "<br></br>" << endl
                << h.font("arial","2") << "Value:" << h._font() << "<br></br>" << endl
                << h.textarea("answer", "", "15", "80") << "<br></br>" << endl
                << h.font("arial","2") << "Keywords:" << h._font() << "<br></br>" << endl
                << h.textarea("keys", "", "4", "30") << "<br></br>" << endl
                << h.in_hidden("question_id" ,question_id) << endl
		<< "<input type=hidden name=instance value=\"" << instance << "\">\n"
                << h.in_submit("Save")
                << h.in_reset("Cancel") << endl
                << h._form() << endl;
	}
	else
	{
		string tmp("");
		int len = answer.length();
		for(int i=0;i<len;i++)
		{
			if(answer[i] == char(39))
			{	
				tmp += "\\'";
			}
			else
				tmp += answer[i];
		}
		//cout << tmp << endl;
		res = db->exec("INSERT INTO %s VALUES(0, %s, '%s', '%s')",MYANSWER, question_id.c_str(), tmp.c_str(), keys.c_str());
		if (res->status() != DB_COMMAND_OK) {
			fprintf(stdout, "Can't insert into table '%s': %s\n\n", MYQUESTION, db->errorMessage());
			delete res;
			delete db;
			exit(1);
		}
		cout << "Data inserted\n";
	}
	Pro p;
	cout << p.back("dbadmin", instance)
	<< h._body()
	<< h._html()
	<< endl;	

	delete res;			// Drop buffer
	delete db;			// Close connection
}

==> faq-system-0.3.2.tar.gz: faq-system-0.3.2/answer.cc <==
#include "conf.h"

int main(void)
{
	//int i;
	char **tuple;
	Database *db;
	DBResult *res;

	db = new Database();

	cgi C;
        C.initPage();

	string instance;
        instance = C.get_value("instance");
        config CONF(instance);

	const char* SCRIPTSUPPORT;
	const char* RUN;
        const char* MYDATABASE;
        const char* MYTOPIC; 
        const char* MYANSWER;
        const char* MYQUESTION;

	const char* USER;
	const char* PASS;
	const char* HOST; 
	HOST = CONF.HOST.c_str();
	USER = CONF.USER.c_str();
	PASS = CONF.PASS.c_str();

        MYDATABASE = CONF.MYDATABASE.c_str();
        MYTOPIC = CONF.MYTOPIC.c_str();
        MYANSWER = CONF.MYANSWER.c_str();  
        MYQUESTION = CONF.MYQUESTION.c_str();
	SCRIPTSUPPORT = CONF.SCRIPTSUPPORT.c_str();
	RUN = CONF.RUN.c_str();

	// Initialise the database - for future releases
	if (db->init() != DB_COMMAND_OK) {
		fprintf(stdout, "Unable to initialize database: %s\n\n", 
		        db->errorMessage());
		exit(0);
        }
	// Connect to database on localhost
        if (db->connect(HOST, "", MYDATABASE, USER, PASS) != DB_CONNECTION_OK) {
        fprintf(stdout, "Unable connect to database '%s': %s\n\n",
                 MYDATABASE, db->errorMessage());
                 exit(0);
        }
	
	string stage, question_id, topic_id, keys, answer, question;
	question_id = C.get_value("question_id");
	answer = C.get_value("answer");
	keys = C.get_value("keys");
	stage = C.get_value("stage");

        topic_id = C.get_value("topic_id");
        question_id = C.get_value("question_id");

	HTML h;
        cout << h.html()
        << h.body("#ffffff") << endl;

	if( stage == "prepare")
	{
		res = db->exec("SELECT value FROM %s WHERE question_id = '%s'", MYQUESTION, question_id.c_str());
		tuple = res->getTuple();
                while (tuple != NULL)
                {
			cout << "<h2>" << *(tuple) << "</h2>\n";
			tuple = res->getTuple();
                }
                cout << "<form name=answer action=\"" << URL << "/" << ADMIN << "/answer.cgi\" method=post>" << endl
                << h.font("arial","2")
                << "Answer this question."
                << h._font() << "<br></br>" << endl
                << h.font("arial","2") << "Value:" << h._font() << "<br></br>" << endl
                << h.textarea("answer", "", "15", "80") << "<br></br>" << endl
                << h.font("arial","2") << "Keywords:" << h._font() << "<br></br>" << endl
                << h.textarea("keys", "", "4", "30") << "<br></br>" << endl
                << h.in_hidden("question_id" ,question_id) << endl
		<< h.in_hidden("topic_id",topic_id) << endl
		<< "<input type=hidden name=instance value=\"" << instance << "\">\n"
                << h.in_submit("Save")
                << h.in_reset("Cancel") << endl
                << h._form() << endl;
	}
	else
	{
		string tmp("");
		int len = answer.length();
		for(int i=0;i<len;i++)
		{
			if(answer[i] == char(39))
			{	
				tmp += "\\'";
			}
			else
				tmp += answer[i];
		}
		//cout << tmp << endl;

		res = db->exec("INSERT INTO %s VALUES(0, %s, '%s', '%s')",MYANSWER, question_id.c_str(), tmp.c_str(), keys.c_str());
		if (res->status() != DB_COMMAND_OK) {
			fprintf(stdout, "Can't insert into table '%s': %s\n\n", MYANSWER, db->errorMessage());
			delete res;
			delete db;
			exit(0);
		}
		cout << "Data inserted\n";


		db->exec(res, "SELECT value FROM %s WHERE question_id = '%s'", MYQUESTION, question_id.c_str());
                tuple = res->getTuple();
                while (tuple != NULL)
                {
                        question =  *(tuple);
                        tuple = res->getTuple();
                }
	}

	Pro p;
	cout << p.back("dbadmin", instance)
        << h._body()
        << h._html()
        << endl; 	
	if((strcmp(SCRIPTSUPPORT, "on")==0) && stage != "prepare")
        {
                string b;
                b = "";
                b += topic_id + "." + question_id + ".";
                p.script("answer.cgi", question, b, instance,string(RUN));
        }  
	delete res;			// Drop buffer
	delete db;			// Close connection
}
